import React, { useState } from 'react';
import { pie, arc, interpolateRgb, scaleOrdinal } from 'd3';
import { Slice } from './Slice';
import { useData } from './useData';
import { keyThemes } from './keyThemes';
import { ColorLegend } from './ColorLegend';
import { transformData } from './transformData';
import { TableSimple } from './TableSimple';

//const data = [1, 2, 3, 4];

const height = 500;
const width = 960;

const innerRadius = 180;
const outerRadius = height / 2;

export const SimplePieChart = () => {
  let data = useData();
  
  const plotVariable = ['#13a9c6', 'rgba(255, 117, 0, 1)', 'rgba(255, 117, 0, 0.85)',  'rgba(255, 117, 0, 0.7)', 'rgba(255, 117, 0, 0.55)', '#9ec4e7'];

  if (!data) {
    return <pre>Loading...</pre>;
  }
  const xValue = (d) => d.Proportion;
  
  let pieGnerator = d3.pie().sort(null)
  let dataPie = data.filter(d => keyThemes.includes(d.Theme));
  
  let sumKeyThemes = 0;
  for(let i = 0; i < dataPie.length; i++) {
  	sumKeyThemes += xValue(dataPie[i]);
  }
  const otherProportion = Math.round((100 - sumKeyThemes) * 100) / 100;
  dataPie.push({Theme: "Ostalo", Proportion: otherProportion});

  
  let pie = pieGnerator(dataPie.map(d => xValue(d)));

  console.log(dataPie);
  
  pie.map((d, i) => {
      d.theme = dataPie[i].Theme;
    })

  keyThemes.push('Ostalo')
  
  const colorScale = scaleOrdinal()
    .domain(keyThemes)
  	.range(plotVariable);
  
  return (
    <>
    <svg height={height} width={width}>
      <g
        transform={`translate(${width * 7 / 10},${height / 2})`}
      >
        <Slice
          pie={pie}
          outerRadius={outerRadius}
          innerRadius={innerRadius}
          colorScale={colorScale}
        />
      </g>
      <g transform={`translate(${150},${height / 2 - 114})`}>
        	<ColorLegend 
            colorScale={colorScale} 
            tickSpacing={50} 
  					tickSize={50} 
  					tickTextOffset={10}
            data={dataPie}
            xValue={xValue}
          />
      </g>
    </svg>
    <TableSimple data={transformData(data)} />
    </>
  );
};
